@@ -28,7 +28,7 @@
 #' - `OrBl_div`
 #' - `PrGn_div`
 #' 
-#' @param palette Name of the `grafify` palettes from above, provide within quotes. Default discrete palette is `okabe_ito`. For quantitative palette, set `discrete = FALSE` (which will apply `blue_conti` unless another palette is chosen).
+#' @param palette Name of the `grafify` palettes from above, provide within quotes, e.g., `palette = "vibrant"`. Default discrete palette is `okabe_ito`. For quantitative palette, set `discrete = FALSE` (which will apply `blue_conti` unless another palette is chosen).
 #' @param reverse Whether the colour order should be reversed.
 #' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours.
 #' @param discrete not used.
@@ -87,7 +87,7 @@ scale_colour_grafify <- function(palette = "okabe_ito", ColSeq = TRUE, reverse =
       pal <- graf_col_palette_default(palette = palette, 
                                       reverse = reverse)
     }
-    discrete_scale("colour", paste0("graf_", palette), 
+    discrete_scale("colour", #paste0("graf_", palette), 
                    palette = pal, ...)}
   
   #  if (palette == "okabe_ito" & discrete == FALSE) {palette <- #"blue_conti"}
